@@ -7,17 +7,45 @@
 from .base import Bugzilla
 from .rhbugzilla import RHBugzilla
 
-
 # These are old compat classes. Nothing new should be added here,
 # and these should not be altered
 
-class Bugzilla3(Bugzilla): pass
-class Bugzilla32(Bugzilla): pass
-class Bugzilla34(Bugzilla): pass
-class Bugzilla36(Bugzilla): pass
-class Bugzilla4(Bugzilla): pass
-class Bugzilla42(Bugzilla): pass
-class Bugzilla44(Bugzilla): pass
-class NovellBugzilla(Bugzilla): pass
-class RHBugzilla3(RHBugzilla): pass
-class RHBugzilla4(RHBugzilla): pass
+
+class Bugzilla3(Bugzilla):
+    pass
+
+
+class Bugzilla32(Bugzilla):
+    pass
+
+
+class Bugzilla34(Bugzilla):
+    pass
+
+
+class Bugzilla36(Bugzilla):
+    pass
+
+
+class Bugzilla4(Bugzilla):
+    pass
+
+
+class Bugzilla42(Bugzilla):
+    pass
+
+
+class Bugzilla44(Bugzilla):
+    pass
+
+
+class NovellBugzilla(Bugzilla):
+    pass
+
+
+class RHBugzilla3(RHBugzilla):
+    pass
+
+
+class RHBugzilla4(RHBugzilla):
+    pass
